@@ -1,11 +1,13 @@
-from typing import Callable, List, Type
+from typing import TYPE_CHECKING, Callable, List, Type
 
 from .decorator import Decorator
-from .dispatcher import BaseDispatcher
 from .event import Dispatchable
 from .exectarget import ExecTarget
 from .namespace import Namespace
 
+if TYPE_CHECKING:
+    from graia.broadcast.typing import T_Dispatcher
+
 
 class Listener(ExecTarget):
     namespace: Namespace
@@ -17,11 +19,11 @@ class Listener(ExecTarget):
         callable: Callable,
         namespace: Namespace,
         listening_events: List[Type[Dispatchable]],
-        inline_dispatchers: List[BaseDispatcher] = None,
-        headless_decorators: List[Decorator] = None,
+        inline_dispatchers: List["T_Dispatcher"] = None,
+        decorators: List[Decorator] = None,
         priority: int = 16,
     ) -> None:
-        super().__init__(callable, inline_dispatchers, headless_decorators)
+        super().__init__(callable, inline_dispatchers, decorators)
 
         self.namespace = namespace
         self.listening_events = listening_events
